<?php
	// this script was developed by Lucas Molleman (CeDEx Nottingham)
	// in the context of a project on social learning.
	// It creates a page in which peers' past decisions are displayed in boxes.
	// For each peer, a separate box is displayed on the screen.
	// When the page is opened, the contents of these boxes are invisible.
	// However, the clients can 'open' the boxes by hovering over them.  
	// This displays the decision the peer made (in this case, 'potato' or 'wheat'). 
	// The payoffs (here: 'revenue') associated with the peers' decisions can be observed as well
	// At first sight, the client cannot evaluate the payoffs.
	// The payoffs can be specified by clicking - and holding - a button inside the box. 
	// this will gradually specify the payoffs.
	// the below code includes comments on both the PHP and the JavaScript code
	
	include("common.inc");
	// specify the number of peers whose decisions can be explored
	$numPlayers=3;
	// for illustratory purposes, create 3 random decisions of peers
	$decisionsOfOthers=array(0,1,0);
	
	// this part of the script is executed when decisions are submitted to the server
	if (isset($_REQUEST['OK'])) 
	{
		// retrieve the variable value from the html form
		$decision=$_REQUEST['decision']; 
		// retrieve array which stores the exploration times of boxes
		$timeExplore=explode(",", $_REQUEST['timeExplore']);
		// retrieve array which stores the number of clicks that specify the payoffs
		$payClicks=explode(",", $_REQUEST['payoffClicks']);
		// write the data to the database 'decisions' using the CREED PEEP standard database 'common.inc' (which should have the respective variables initialised)
		insertRecord("decisions","ppnr, period, decision, exploreTime0, exploreTime1, exploreTime2, payClicks0, payClicks1, payClicks2",
								"'$ppnr', '$period', '$decision', '$timeExplore[0]', '$timeExplore[1]', '$timeExplore[2]', '$payClicks[0]', '$payClicks[1]', '$payClicks[2]'");
	
		// proceed to the next screen
		header("Location: result.php");
		exit();
	}
?>

<!DOCTYPE html>
<title>Exploration task</title>
<head>
<!-- load jQuery and SVG (two libraries to enable live interaction with screen) -->
<script src="http://code.jquery.com/jquery-latest.min.js" type="text/javascript"></script>
<script src="//cdn.jsdelivr.net/svg.js/0.6/svg.min.js"></script>

<script language="JavaScript">
	// specify number of players in group (read from server)
	var numPlayers = <?php echo json_encode($numPlayers); ?>;
	// if value is taken from the server, it might need parsing so that JavaScript treats it like an integer	
	var numP=parseInt(numPlayers);
	// declare array variables {1,2,3} to store the exploration times in boxes {1,2,3} in, and set all values to 0
	var timeOnBox=[]; payoffClicks=[]; t0=[]; t1=[]; 
	for (var j=0; j<numP; ++j)
	{
		timeOnBox[j]=0; payoffClicks[j]=0; t0[j]=0; t1[j]=0;
	}
	// measure the current time
	var timeStart = new Date().getTime();
	// this is the payoff that the peer got for his choice. The real value should be read from the database. Here, I just set it to 50. 
	var target=50; 
	// The library SVG prints the values upside down to the screen... (so subtract from the maximum payoff value of 200)
	var adjTarget = 200 - target;

	// the following jQuery script ensures that each click on the 'specify payoffs'-button makes the bar shorter, so that the noise on the observed payoff decreases!
	var timeout;
	$(document).ready(function()
	{
		$(".payoffSpecifier").mousedown(function()
		{
			var thisBox = this.id;
			var i = parseInt(thisBox.substr(thisBox.length - 1));
			timeout = setInterval(function(){specify(i);}, 10);
				return false;
		});
		$(document).mouseup(function(){
			clearInterval(timeout);
			return false;
			});
	});

	function specify(i)
	{	
		payoffClicks[i]+=1;
		
		var minRange = 4;	// should be large enough so that y1New > y2New always holds
		
		var curmin = payoffLine[i].attr("y1") - 10;
		var curmax = payoffLine[i].attr("y2") - 10;

		var distMax = parseInt(curmax) - adjTarget;
		var distMin = adjTarget - parseInt(curmin);
		var relToMax = distMax / (distMax + distMin);
		var y1New = parseInt(curmin) + 1;
		var y2New = parseInt(curmax) - 1;
		if (distMax > minRange && distMin > minRange)
		// we are far from the target; go either way.
		{
			if (Math.random() > relToMax) 
				{payoffLine[i].attr("y1", (y1New + 10 ) );}
			else 
				{payoffLine[i].attr("y2", (y2New + 10) )};
		}
		else
		{
			if (distMin > minRange) // x2 is close to the target, but x1 is not
				{payoffLine[i].attr("y1", (y1New + 10) );}
			else
			{
				if (distMax > minRange) // x1 is close to the target, but x2 is not
				{payoffLine[i].attr("y2", (y2New + 10 ) );}
			}
		}
		if (distMax < minRange && distMin < minRange) {alert('klaar');}
	};
	
	// this script shows the 'contents' of a box when the client hovers over it.
	// basically it makes the otherwise opaque background transparent
	var k=0;
	$(document).ready(function()
	{
		$("div.enter").hover(function()
		{
			$(this).css("background-color","transparent");
			$(this).find(".image").css("opacity","1");
			var thisBox = $(this).attr('id');
			k = parseInt(thisBox.substr(thisBox.length - 1));
			t0[k] = new Date().getTime();
		},
		function()
		{
			$(this).css("background-color","dodgerblue");
			$(this).find(".image").css("opacity","0");
			t1[k] = new Date().getTime();
			timeOnBox[k] += t1[k]-t0[k];
			$("#measureTime").val(timeOnBox[2]);
			$("#measureClicks").val(payoffClicks[2]);
		}
		);
	});	
	
	// this script sets the value of the client's choice when he clicks the option.
	var decisionThisRound='NA';
	$(function () 
	{
		$("img.clickOption").click(function() 
		{
			// adjust the decision value upon click
			if (this.id=="option_0")
			{
				decisionThisRound=0;
			}
			if (this.id=="option_1")
			{
				decisionThisRound=1;
			}
	// draw a border around selected item (and remove border around other items)
			$("img").css('border-color', "transparent");
			$(this).css('border-color', "orangered");  
		});
	});
	// check if the subject has made a decision (script is executed when subject clicks 'confirm')
	// when no decision has been made, the client cannot proceed and receives an alert box.
	$(function() 
	{
		$(".resetInput").on("click", function() {
			if (decisionThisRound==0 || decisionThisRound==1)
			{
				// submit the form to the server when decision has indeed been made
				$(".decisionData").val(decisionThisRound);
				$(".exploreData").val(timeOnBox);
				$(".clickData").val(payoffClicks);
			}
			else
			{
				alert('Please make a decision!');
				return false;
			}
		});
	})

</script>

<body>
<script>
// create a variable to store the different boxes in
	var boxes=[]; var payoffLine=[];
	// tell Javascript how many peers are in the game
	var numPlayers = <?php echo json_encode($numPlayers); ?>;
	// parse the value to integer
	var numP = parseInt(numPlayers);
	// read the decisions of the peers from the server
	var decs= <?php echo json_encode($decisionsOfOthers); ?>;
	// again, parse the values to integers
	var decisions=[];

	for(var k=0; k<numP; ++k) {decisions[k]=parseInt(decs[k]);};
	// loop through all players to create the html script to write to the client's screen
	for (var player=0; player<numP; ++player)
	{
		// create variable to store the box of each player in
		var b = "box";
		// create a unique name for this box
		var boxName=b.concat(player);
		// retrieve the decision of this player		
		var decision = decisions[player];	
		// create container to put stuff in;
		boxes[player]=document.createElement("div");
		// create a string to specify the layout of the box, and give the box some attributes
		var stylestring = "background-color:dodgerblue; padding:20px; width:250px; float:left; border:2px solid #a1a1a1; border-radius:25px; width:150px; height:450px; margin:10px";
		boxes[player].setAttribute("class","enter"); boxes[player].setAttribute("id", boxName); boxes[player].setAttribute("align", "center");  
		boxes[player].setAttribute("style", stylestring);
		// create image to put in boxes[player], give it an ID and some layout attributes
		var img=document.createElement("img"); img.setAttribute("class", "image");
		var idstring = "imageDecision"; //idstring=idstring.concat(player);
		var stylestring2 = "opacity:0; float:left";
		
		// find the picture corresponding to the decision
		// in this game, clients could choose between two options by clicking on images ('potato' or 'wheat')
		var imString;
		if (decision==0) {imString="potato.jpg";}
		if (decision==1) {imString="wheat.jpg";}
		// set the specifications of the picture
		img.setAttribute("border", "0"); img.setAttribute("id", idstring); img.setAttribute("src", imString);
		img.setAttribute("width", "145px"); img.setAttribute("height", "145px"); img.setAttribute("style", stylestring2);
		// append the picture to the box
		boxes[player].appendChild(img);
		// create button to put in the box (including some style attributes to link it to the above jQuery program to make live changes)
		var but=document.createElement("button");
		var stylestring3 = "background-color:transparent; border-color:#1E90FF; border:3px solid #1E90FF; color=#1E90FF;";
		var specstring = "specify("; specstring = specstring.concat(player,")");
		var idstring = "payoff"; idstring = idstring.concat(player);
		but.setAttribute("id", idstring); but.setAttribute("class", "payoffSpecifier"); // this defines the class to make the jQuery code work
		but.setAttribute("style", stylestring3);
		// set button text layout, text and append to button
		but.style.font="bold 20px serif"; but.style.color="#1E90FF";
		var t=document.createTextNode("Specify revenue");
		but.appendChild(t);
		boxes[player].appendChild(but);
		// append the whole container to the document
		document.body.appendChild(boxes[player]);
		var draw = svg(boxName).size(150,220);
		// draw the initial (unspecified) payoff line
		var line = draw.line(110, 10, 110, 210).stroke({color: 'dodgerblue', width: 3 });
		payoffLine[player] = draw.line(75, 10, 75, 210).stroke({color: 'dodgerblue', width: 6 });
		for (var i=0; i<=200; i=i+50)
		{
			var i1 = 200 - i;
			var lines = draw.line(105,i1+10,115,i1+10).stroke({ color: 'dodgerblue', width: 1 })
			var n = i1.toString();
			var text = draw.text(n).move(120, i).stroke( {color: 'dodgerblue' })
		}
	}

</script>
<!-- go to next line -->
<div style="clear:both"></div> 
<!-- specify the decision area -->
<div id="decisionThisRound1" style="align:center; width:700px; height:250px; margin:0 auto; border-style:solid">
<p> <font size="5" style="padding-left:20px"> Your decision in this round: </p>

<!-- go to next line -->
<!-- print the two decision options to the screen -->
<img src="potato.jpg" alt="potato" id="option_0" class="clickOption"
	style="width:145px; height:145px; padding-right:50px; padding-left:50px;
	border:5px solid transparent; border-radius:25px; margin:20px" />
	
<img src="wheat.jpg" alt="wheat" id="option_1" class="clickOption"
	style="width:145px; height:145px; padding-right:50px; padding-left:50px;
	border:5px solid transparent; border-radius:25px; margin:20px" />

	<!-- show the 'Submit!' box -->
	<!-- this includes the variables collected by the HTML form -->
	<div id="Submit_decision">
		<form name="form1" action="<?php echo $_SERVER['PHP_SELF']; ?>" method="post">
			<input type="hidden" name="timeExplore" value="" class="exploreData" />
			<input type="hidden" name="payoffClicks" value="" class="clickData" />
			<input type="hidden" name="decisionThisRound" value="" class="decisionData" />
			<button type="submit" name="OK" value="OK" class="resetInput" > Submit! </button> 
		</form>
	</div>
</div>


<script>
</script>
</body>

</html>